@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
-# Minio Python Library for Amazon S3 Compatible Cloud Storage,
-# (C) 2015, 2016, 2017 Minio, Inc.
+# MinIO Python Library for Amazon S3 Compatible Cloud Storage,
+# (C) 2015, 2016, 2017 MinIO, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,10 +18,10 @@
 minio.error
 ~~~~~~~~~~~~~~~~~~~
 
-This module provides custom exception classes for Minio library
+This module provides custom exception classes for MinIO library
 and API specific errors.
 
-:copyright: (c) 2015, 2016, 2017 by Minio, Inc.
+:copyright: (c) 2015, 2016, 2017 by MinIO, Inc.
 :license: Apache 2.0, see LICENSE for more details.
 
 """
@@ -133,8 +133,6 @@ class ResponseError(MinioError):
         self.object_name = object_name
         # initialize all ResponseError fields
         self.code = ''
-        self.bucket_name = ''
-        self.object_name = ''
         # Amz headers
         self.request_id = ''
         self.host_id = ''
@@ -212,7 +210,7 @@ class ResponseError(MinioError):
                     self.code = 'NoSuchBucket'
                     self.message = self._response.reason
         elif self._response.status == 409:
-            self.code = 'Confict'
+            self.code = 'Conflict'
             self.message = 'The bucket you tried to delete is not empty.'
         elif self._response.status == 403:
             self.code = 'AccessDenied'
